@@ -11,7 +11,7 @@ import pango
 import hashlib          
 import StringIO
 DB_FORMAT = '%Y-%m-%d'
-FRAMEWORK_VERSION = '0.2.1' 
+FRAMEWORK_VERSION = '0.2.7' 
 DB_PATH = '/home/user/.mPIM/mnotes.db'
 DB_IMG_FOLDER = '/home/user/.mPIM/mnotes_img/'
 
@@ -41,7 +41,7 @@ class Database:
           commands.getoutput("mkdir /home/user/.mPIM/")
           self.db = sqlite3.connect(self.path)
           self.cursor = self.db.cursor()
-          self.cursor.execute('CREATE TABLE notes (uuid TEXT PRIMARY KEY, title DATETIME, description TEXT,photo BINARY,draw BINARY)')
+          self.cursor.execute('CREATE TABLE notes (uuid TEXT PRIMARY KEY, title DATETIME, description TEXT,type INTEGER)')
           self.db.commit()
           self.cursor.execute('CREATE TABLE db_struct (version TEXT);')
           self.db.commit()
@@ -66,7 +66,7 @@ class Database:
 #              self.cursor.execute('ALTER TABLE notes ADD COLUMN photo BINARY')
 #              self.cursor.execute('ALTER TABLE notes ADD COLUMN draw BINARY')
               self.db.commit()
-            if version < '0.2.1':
+            if version < '0.2.7':
                 self.cursor.execute('ALTER TABLE notes ADD COLUMN type INTEGER')
 
           except:
